Struct ZwpTabletPadV2

pub struct ZwpTabletPadV2 { /* private fields */ }
Available on crate feature wayland and Linux only.
a set of buttons, rings, strips and dials

A pad device is a set of buttons, rings, strips and dials usually physically present on the tablet device itself. Some exceptions exist where the pad device is physically detached, e.g. the Wacom ExpressKey Remote.

Pad devices have no axes that control the cursor and are generally auxiliary devices to the tool devices used on the tablet surface.

A pad device has a number of static characteristics, e.g. the number of rings. These capabilities are sent in an event sequence after the zwp_tablet_seat_v2.pad_added event before any actual events from this pad. This initial event sequence is terminated by a zwp_tablet_pad_v2.done event.

All pad features (buttons, rings, strips and dials) are logically divided into groups and all pads have at least one group. The available groups are notified through the zwp_tablet_pad_v2.group event; the compositor will emit one event per group before emitting zwp_tablet_pad_v2.done.

Groups may have multiple modes. Modes allow clients to map multiple actions to a single pad feature. Only one mode can be active per group, although different groups may have different active modes.

See also the Request enum for this interface.

Implementations



impl ZwpTabletPadV2

pub fn group(&self, pad_group: &ZwpTabletPadGroupV2)

group announced

Sent on zwp_tablet_pad_v2 initialization to announce available groups. One event is sent for each pad group available.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event. At least one group will be announced.

pub fn path(&self, path: String)

path to the device

A system-specific device path that indicates which device is behind this zwp_tablet_pad_v2. This information may be used to gather additional information about the device, e.g. through libwacom.

The format of the path is unspecified, it may be a device node, a sysfs path, or some other identifier. It is up to the client to identify the string provided.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event.

pub fn buttons(&self, buttons: u32)

buttons announced

Sent on zwp_tablet_pad_v2 initialization to announce the available buttons.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event. This event is only sent when at least one button is available.

pub fn done(&self)

pad description event sequence complete

This event signals the end of the initial burst of descriptive events. A client may consider the static description of the pad to be complete and finalize initialization of the pad.

pub fn button(&self, time: u32, button: u32, state: ButtonState)

physical button state

Sent whenever the physical state of a button changes.

pub fn enter(&self, serial: u32, tablet: &ZwpTabletV2, surface: &WlSurface)

enter event

Notification that this pad is focused on the specified surface.

pub fn leave(&self, serial: u32, surface: &WlSurface)

leave event

Notification that this pad is no longer focused on the specified surface.

pub fn removed(&self)

pad removed event

Sent when the pad has been removed from the system. When a tablet is removed its pad(s) will be removed too.

When this event is received, the client must destroy all rings, strips and groups that were offered by this pad, and issue zwp_tablet_pad_v2.destroy the pad itself.